summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRucha Deodhar <rucha.deodhar@mariadb.com>2021-02-08 14:52:04 +0530
committerRucha Deodhar <rucha.deodhar@mariadb.com>2021-05-25 17:51:19 +0530
commit0b8dd57c46ee1265e327b010e80ffcc5d2fd0332 (patch)
tree43a82258df3a46c88a2fd0ffb9a4bc612b44a17c
parent4e19539c1484a9b23e01601f88b14c450279780a (diff)
downloadmariadb-git-0b8dd57c46ee1265e327b010e80ffcc5d2fd0332.tar.gz
MDEV-22010: use executables MariaDB named in scripts
As a part of this MDEV following changes were made: 1) Mariadb named executables used instead of mysql named executables in scripts 2) renamed mysql-test-run and mysql-stress-test to mariadb-test-run and mariadb-stress-test and created a symlink.
-rw-r--r--.gitignore3
-rw-r--r--debian/mariadb-test.install3
-rw-r--r--debian/mariadb-test.links6
-rw-r--r--mysql-test/CMakeLists.txt42
-rw-r--r--mysql-test/lib/mtr_stress.pl2
-rw-r--r--mysql-test/lib/v1/mtr_stress.pl2
-rwxr-xr-xmysql-test/mariadb-stress-test.pl (renamed from mysql-test/mysql-stress-test.pl)0
-rwxr-xr-xmysql-test/mariadb-test-run.pl (renamed from mysql-test/mysql-test-run.pl)8
-rw-r--r--mysql-test/mtr.out-of-source2
-rw-r--r--mysql-test/suite/stress/t/wrapper.test2
-rw-r--r--scripts/CMakeLists.txt8
-rw-r--r--scripts/mysql_install_db.sh20
-rw-r--r--scripts/mysql_secure_installation.sh8
-rw-r--r--scripts/mysqlaccess.sh6
-rw-r--r--scripts/mysqld_multi.sh32
-rw-r--r--scripts/mysqld_safe.sh3
-rw-r--r--scripts/wsrep_sst_common.sh20
17 files changed, 107 insertions, 60 deletions
diff --git a/.gitignore b/.gitignore
index 4fee2deaea5..0443c18e38c 100644
--- a/.gitignore
+++ b/.gitignore
@@ -90,6 +90,9 @@ mysql-test/lib/My/SafeProcess/my_safe_process
mysql-test/lib/My/SafeProcess/wsrep_check_version
mysql-test/mtr
mysql-test/mysql-test-run
+mysql-test/mariadb-test-run
+mysql-test/mysql-stress-test.pl
+mysql-test/mysql-test-run.pl
mysql-test/var*
mysql-test-gcov.err
mysql-test-gcov.msg
diff --git a/debian/mariadb-test.install b/debian/mariadb-test.install
index bbcc200c368..b9181608368 100644
--- a/debian/mariadb-test.install
+++ b/debian/mariadb-test.install
@@ -25,6 +25,7 @@ usr/share/man/man1/mariadb-client-test-embedded.1
usr/share/man/man1/mariadb-client-test.1
usr/share/man/man1/mariadb-test-embedded.1
usr/share/man/man1/mariadb-test.1
+usr/share/man/man1/mariadb-stress-test.pl.1
usr/share/man/man1/mysql-stress-test.pl.1
usr/share/man/man1/mysql-test-run.pl.1
usr/share/man/man1/mysql_client_test.1
@@ -37,7 +38,9 @@ usr/share/mysql/mysql-test/README.stress
usr/share/mysql/mysql-test/dgcov.pl
usr/share/mysql/mysql-test/lib
usr/share/mysql/mysql-test/mysql-stress-test.pl
+usr/share/mysql/mysql-test/mariadb-stress-test.pl
usr/share/mysql/mysql-test/mysql-test-run.pl
+usr/share/mysql/mysql-test/mariadb-test-run.pl
usr/share/mysql/mysql-test/purify.supp
usr/share/mysql/mysql-test/suite.pm
usr/share/mysql/mysql-test/valgrind.supp
diff --git a/debian/mariadb-test.links b/debian/mariadb-test.links
index 718a5355474..b3577667d01 100644
--- a/debian/mariadb-test.links
+++ b/debian/mariadb-test.links
@@ -2,5 +2,7 @@ usr/bin/mariadb-client-test usr/bin/mysql_client_test
usr/bin/mariadb-client-test-embedded usr/bin/mysql_client_test_embedded
usr/bin/mariadb-test usr/bin/mysqltest
usr/bin/mariadb-test-embedded usr/bin/mysqltest_embedded
-usr/share/mysql/mysql-test/mysql-test-run.pl usr/share/mysql/mysql-test/mtr
-usr/share/mysql/mysql-test/mysql-test-run.pl usr/share/mysql/mysql-test/mysql-test-run
+usr/share/mysql/mysql-test/mariadb-test-run.pl usr/share/mysql/mysql-test/mysql-test-run.pl
+usr/share/mysql/mysql-test/mariadb-stress-test.pl usr/share/mysql/mysql-test/mysql-stress-test.pl
+usr/share/mysql/mysql-test/mariadb-test-run.pl usr/share/mysql/mysql-test/mysql-test-run
+usr/share/mysql/mysql-test/mariadb-test-run.pl usr/share/mysql/mysql-test/mtr
diff --git a/mysql-test/CMakeLists.txt b/mysql-test/CMakeLists.txt
index 7487e301df5..afa2d0776d3 100644
--- a/mysql-test/CMakeLists.txt
+++ b/mysql-test/CMakeLists.txt
@@ -19,27 +19,53 @@ INSTALL_MYSQL_TEST("." ".")
IF(NOT ${CMAKE_SOURCE_DIR} STREQUAL ${CMAKE_BINARY_DIR})
# Enable running mtr from build directory
CONFIGURE_FILE(
- ${CMAKE_CURRENT_SOURCE_DIR}/mtr.out-of-source
- ${CMAKE_CURRENT_BINARY_DIR}/mysql-test-run.pl
+ ${CMAKE_CURRENT_SOURCE_DIR}/mtr.out-of-source
+ ${CMAKE_CURRENT_BINARY_DIR}/mariadb-test-run.pl
@ONLY
)
SET(out_of_source_build TRUE)
ENDIF()
IF(UNIX)
EXECUTE_PROCESS(
- COMMAND chmod +x mysql-test-run.pl
- COMMAND ${CMAKE_COMMAND} -E create_symlink
- ./mysql-test-run.pl mtr
- COMMAND ${CMAKE_COMMAND} -E create_symlink
- ./mysql-test-run.pl mysql-test-run
+ COMMAND chmod +x mariadb-test-run.pl
+ COMMAND ${CMAKE_COMMAND} -E create_symlink
+ ./mariadb-test-run.pl mysql-test-run.pl
+ COMMAND ${CMAKE_COMMAND} -E create_symlink
+ ./mariadb-test-run.pl mysql-test-run
+ COMMAND ${CMAKE_COMMAND} -E create_symlink
+ ./mariadb-test-run.pl mtr
+ COMMAND ${CMAKE_COMMAND} -E create_symlink
+ ./mariadb-test-run.pl mariadb-test-run
WORKING_DIRECTORY ${CMAKE_CURRENT_BINARY_DIR}
- )
+ )
+ EXECUTE_PROCESS(
+ COMMAND chmod +x mariadb-stress-test.pl
+ COMMAND ${CMAKE_COMMAND} -E create_symlink
+ mariadb-stress-test.pl mysql-stress-test.pl
+ WORKING_DIRECTORY ${CMAKE_CURRENT_SOURCE_DIR}
+ )
IF(INSTALL_MYSQLTESTDIR AND out_of_source_build)
INSTALL(FILES ${CMAKE_CURRENT_BINARY_DIR}/mtr
${CMAKE_CURRENT_BINARY_DIR}/mysql-test-run
+ ${CMAKE_CURRENT_BINARY_DIR}/mysql-test-run.pl
+ ${CMAKE_CURRENT_BINARY_DIR}/mariadb-test-run
DESTINATION ${INSTALL_MYSQLTESTDIR}
COMPONENT Test)
ENDIF()
+ELSE()
+ FILE(REMOVE mysql-test-run.pl)
+ EXECUTE_PROCESS(COMMAND mklink /H
+ mysql-test-run.pl mariadb-test-run.pl
+ WORKING_DIRECTORY ${CMAKE_CURRENT_BINARY_DIR})
+ EXECUTE_PROCESS(COMMAND mklink /H
+ mysql-stress-test.pl mariadb-stress-test.pl
+ WORKING_DIRECTORY ${CMAKE_CURRENT_SOURCE_DIR})
+ IF(INSTALL_MYSQLTESTDIR)
+ INSTALL(FILES ${CMAKE_CURRENT_BINARY_DIR}/mariadb-test-run.pl
+ RENAME mysql-test-run.pl
+ DESTINATION ${INSTALL_MYSQLTESTDIR}
+ COMPONENT Test)
+ ENDIF()
ENDIF()
IF(CMAKE_GENERATOR MATCHES "Visual Studio")
diff --git a/mysql-test/lib/mtr_stress.pl b/mysql-test/lib/mtr_stress.pl
index 09c30d0988a..cf7064cb68f 100644
--- a/mysql-test/lib/mtr_stress.pl
+++ b/mysql-test/lib/mtr_stress.pl
@@ -136,7 +136,7 @@ sub run_stress_test ()
}
mtr_init_args(\$args);
- mtr_add_args($args, "$::glob_mysql_test_dir/mysql-stress-test.pl");
+ mtr_add_args($args, "$::glob_mysql_test_dir/mariadb-stress-test.pl");
mtr_add_arg($args, "--server-socket=%s", $::master->[0]->{'path_sock'});
mtr_add_arg($args, "--server-user=%s", $::opt_user);
mtr_add_arg($args, "--server-database=%s", "test");
diff --git a/mysql-test/lib/v1/mtr_stress.pl b/mysql-test/lib/v1/mtr_stress.pl
index c19eb86ec9b..c96469a5d94 100644
--- a/mysql-test/lib/v1/mtr_stress.pl
+++ b/mysql-test/lib/v1/mtr_stress.pl
@@ -182,7 +182,7 @@ sub run_stress_test ()
}
#Run stress test
- mtr_run("$::glob_mysql_test_dir/mysql-stress-test.pl", $args, "", "", "", "");
+ mtr_run("$::glob_mysql_test_dir/mariadb-stress-test.pl", $args, "", "", "", "");
if ( ! $::glob_use_embedded_server )
{
stop_all_servers();
diff --git a/mysql-test/mysql-stress-test.pl b/mysql-test/mariadb-stress-test.pl
index 3ccf965024d..3ccf965024d 100755
--- a/mysql-test/mysql-stress-test.pl
+++ b/mysql-test/mariadb-stress-test.pl
diff --git a/mysql-test/mysql-test-run.pl b/mysql-test/mariadb-test-run.pl
index fa68a017ff2..335840b6358 100755
--- a/mysql-test/mysql-test-run.pl
+++ b/mysql-test/mariadb-test-run.pl
@@ -35,7 +35,7 @@ use warnings;
BEGIN {
# Check that mysql-test-run.pl is started from mysql-test/
- unless ( -f "mysql-test-run.pl" )
+ unless ( -f "mariadb-test-run.pl" )
{
print "**** ERROR **** ",
"You must start mysql-test-run from the mysql-test/ directory\n";
@@ -57,10 +57,10 @@ BEGIN {
if ( $version == 1 )
{
print "=======================================================\n";
- print " WARNING: Using mysql-test-run.pl version 1! \n";
+ print " WARNING: Using mariadb-test-run.pl version 1! \n";
print "=======================================================\n";
# Should use exec() here on *nix but this appears not to work on Windows
- exit(system($^X, "lib/v1/mysql-test-run.pl", @ARGV) >> 8);
+ exit(system($^X, "lib/v1/mariadb-test-run.pl", @ARGV) >> 8);
}
elsif ( $version == 2 )
{
@@ -69,7 +69,7 @@ BEGIN {
}
else
{
- print "ERROR: Version $version of mysql-test-run does not exist!\n";
+ print "ERROR: Version $version of mariadb-test-run does not exist!\n";
exit(1);
}
}
diff --git a/mysql-test/mtr.out-of-source b/mysql-test/mtr.out-of-source
index 30e2e65c569..abab0be90df 100644
--- a/mysql-test/mtr.out-of-source
+++ b/mysql-test/mtr.out-of-source
@@ -2,4 +2,4 @@
# Call mtr in out-of-source build
$ENV{MTR_BINDIR} = '@CMAKE_BINARY_DIR@';
chdir('@CMAKE_SOURCE_DIR@/mysql-test');
-exit(system($^X, '@CMAKE_SOURCE_DIR@/mysql-test/mysql-test-run.pl', @ARGV) >> 8);
+exit(system($^X, '@CMAKE_SOURCE_DIR@/mysql-test/mariadb-test-run.pl', @ARGV) >> 8);
diff --git a/mysql-test/suite/stress/t/wrapper.test b/mysql-test/suite/stress/t/wrapper.test
index 4d2dd808a4c..7a468985570 100644
--- a/mysql-test/suite/stress/t/wrapper.test
+++ b/mysql-test/suite/stress/t/wrapper.test
@@ -20,7 +20,7 @@ EOF
--source $MYSQL_TMP_DIR/mtest.inc
--remove_file $MYSQL_TMP_DIR/mtest.inc
-exec perl mysql-stress-test.pl --mysqltest=$MYSQLTEST_BIN
+exec perl mariadb-stress-test.pl --mysqltest=$MYSQLTEST_BIN
--server-port=$MASTER_MYPORT --server-socket=$MASTER_MYSOCK
--server-user=root --cleanup
--server-logs-dir=$MYSQLTEST_VARDIR/log
diff --git a/scripts/CMakeLists.txt b/scripts/CMakeLists.txt
index 7d1f10e5ba2..02595e8bc04 100644
--- a/scripts/CMakeLists.txt
+++ b/scripts/CMakeLists.txt
@@ -146,11 +146,11 @@ IF(UNIX)
# FIND_PROC and CHECK_PID are used by mysqld_safe
IF(CMAKE_SYSTEM_NAME MATCHES "Linux")
SET (FIND_PROC
- "ps wwwp $PID | grep -v mysqld_safe | grep -- $MYSQLD > /dev/null")
+ "ps wwwp $PID | grep -vE mariadbd-safe -vE mysqld_safe | grep -- $MYSQLD > /dev/null")
ENDIF()
IF(NOT FIND_PROC AND CMAKE_SYSTEM_NAME MATCHES "SunOS")
SET (FIND_PROC
- "ps -p $PID | grep -v mysqld_safe | grep -- $MYSQLD > /dev/null")
+ "ps -p $PID | grep -v mariadbd-safe | grep -- $MYSQLD > /dev/null")
ENDIF()
IF(NOT FIND_PROC)
@@ -158,7 +158,7 @@ IF(NOT FIND_PROC)
EXECUTE_PROCESS(COMMAND ps -uaxww OUTPUT_QUIET ERROR_QUIET RESULT_VARIABLE result)
IF(result MATCHES 0)
SET( FIND_PROC
- "ps -uaxww | grep -v mysqld_safe | grep -- $MYSQLD | grep $PID > /dev/null")
+ "ps -uaxww | grep -v mariadbd-safe | grep -- $MYSQLD | grep $PID > /dev/null")
ENDIF()
ENDIF()
@@ -166,7 +166,7 @@ IF(NOT FIND_PROC)
# SysV style
EXECUTE_PROCESS(COMMAND ps -ef OUTPUT_QUIET ERROR_QUIET RESULT_VARIABLE result)
IF(result MATCHES 0)
- SET( FIND_PROC "ps -ef | grep -v mysqld_safe | grep -- $MYSQLD | grep $PID > /dev/null")
+ SET( FIND_PROC "ps -ef | grep -v mariadbd-safe | grep -- $MYSQLD | grep $PID > /dev/null")
ENDIF()
ENDIF()
diff --git a/scripts/mysql_install_db.sh b/scripts/mysql_install_db.sh
index 6b0c78ef702..f8e69e9a755 100644
--- a/scripts/mysql_install_db.sh
+++ b/scripts/mysql_install_db.sh
@@ -315,7 +315,7 @@ parse_arguments `"$print_defaults" $defaults $defaults_group_suffix --mysqld mys
parse_arguments PICK-ARGS-FROM-ARGV "$@"
-rel_mysqld="$dirname0/@INSTALL_SBINDIR@/mysqld"
+rel_mysqld="$dirname0/@INSTALL_SBINDIR@/mariadbd"
# Configure paths to support files
if test -n "$srcdir"
@@ -338,11 +338,11 @@ then
cannot_find_file resolveip @resolveip_locations@
exit 1
fi
- mysqld=`find_in_dirs mysqld @mysqld_locations@`
+ mysqld=`find_in_dirs mariadbd @mysqld_locations@`
if test -z "$mysqld"
then
- cannot_find_file mysqld @mysqld_locations@
- exit 1
+ cannot_find_file mariadbd @mysqld_locations@
+ exit 1
fi
langdir=`find_in_dirs --dir errmsg.sys @errmsg_locations@`
if test -z "$langdir"
@@ -360,7 +360,7 @@ then
plugindir=`find_in_dirs --dir auth_pam.so $basedir/lib*/plugin $basedir/lib*/mysql/plugin $basedir/lib/*/mariadb19/plugin`
pamtooldir=$plugindir
# relative from where the script was run for a relocatable install
-elif test -n "$dirname0" -a -x "$rel_mysqld" -a ! "$rel_mysqld" -ef "@sbindir@/mysqld"
+elif test -n "$dirname0" -a -x "$rel_mysqld" -a ! "$rel_mysqld" -ef "@sbindir@/mariadbd"
then
basedir="$dirname0"
bindir="$basedir/@INSTALL_BINDIR@"
@@ -374,7 +374,7 @@ else
basedir="@prefix@"
bindir="@bindir@"
resolveip="$bindir/resolveip"
- mysqld="@sbindir@/mysqld"
+ mysqld="@sbindir@/mariadbd"
srcpkgdatadir="@pkgdatadir@"
buildpkgdatadir="@pkgdatadir@"
plugindir="@pkgplugindir@"
@@ -580,7 +580,7 @@ else
echo
echo " shell> $mysqld --skip-grant-tables --general-log &"
echo
- echo "and use the command line tool $bindir/mysql"
+ echo "and use the command line tool $bindir/mariadb"
echo "to connect to the mysql database and look at the grant tables:"
echo
echo " shell> $bindir/mysql -u root mysql"
@@ -614,11 +614,11 @@ then
echo "PLEASE REMEMBER TO SET A PASSWORD FOR THE MariaDB root USER !"
echo "To do so, start the server, then issue the following commands:"
echo
- echo "'$bindir/mysqladmin' -u root password 'new-password'"
- echo "'$bindir/mysqladmin' -u root -h $hostname password 'new-password'"
+ echo "'$bindir/mariadb-admin' -u root password 'new-password'"
+ echo "'$bindir/mariadb-admin' -u root -h $hostname password 'new-password'"
echo
echo "Alternatively you can run:"
- echo "'$bindir/mysql_secure_installation'"
+ echo "'$bindir/mariadb-secure-installation'"
echo
echo "which will also give you the option of removing the test"
echo "databases and anonymous user created by default. This is"
diff --git a/scripts/mysql_secure_installation.sh b/scripts/mysql_secure_installation.sh
index b2a9edf4953..40d8e5d330e 100644
--- a/scripts/mysql_secure_installation.sh
+++ b/scripts/mysql_secure_installation.sh
@@ -159,15 +159,15 @@ then
cannot_find_file my_print_defaults $basedir/bin $basedir/extra
exit 1
fi
- mysql_command=`find_in_basedir mysql bin`
+ mysql_command=`find_in_basedir mariadb bin`
if test -z "$mysql_command"
then
- cannot_find_file mysql $basedir/bin
- exit 1
+ cannot_find_file mariadb $basedir/bin
+ exit 1
fi
else
print_defaults="@bindir@/my_print_defaults"
- mysql_command="@bindir@/mysql"
+ mysql_command="@bindir@/mariadb"
fi
if test ! -x "$print_defaults"
diff --git a/scripts/mysqld_safe.sh b/scripts/mysqld_safe.sh
index 126eb924814..d1819e0b115 100644
--- a/scripts/mysqld_safe.sh
+++ b/scripts/mysqld_safe.sh
@@ -531,7 +531,8 @@ else
ledir='@libexecdir@'
fi
-helper=`find_in_bin mysqld_safe_helper`
+helper=`find_in_bin mariadbd-safe-helper`
+
print_defaults=`find_in_bin my_print_defaults`
# Check if helper exists
command -v $helper --help >/dev/null 2>&1
diff --git a/scripts/wsrep_sst_common.sh b/scripts/wsrep_sst_common.sh
index f4ac2e9936d..4407c1ba557 100644
--- a/scripts/wsrep_sst_common.sh
+++ b/scripts/wsrep_sst_common.sh
@@ -599,16 +599,28 @@ SCRIPTS_DIR=$(cd "$script_binary"; pwd -P)
EXTRA_DIR="$SCRIPTS_DIR/../extra"
CLIENT_DIR="$SCRIPTS_DIR/../client"
-if [ -x "$CLIENT_DIR/mysql" ]; then
- MYSQL_CLIENT="$CLIENT_DIR/mysql"
+if [ -x "$CLIENT_DIR/mariadb" ]; then
+ MYSQL_CLIENT="$CLIENT_DIR/mariadb"
else
+<<<<<<< HEAD
MYSQL_CLIENT="$(command -v mysql)"
+||||||| constructed merge base
+ MYSQL_CLIENT=mysql
+=======
+ MYSQL_CLIENT=mariadb
+>>>>>>> MDEV-22010: use executables MariaDB named in scripts
fi
-if [ -x "$CLIENT_DIR/mysqldump" ]; then
- MYSQLDUMP="$CLIENT_DIR/mysqldump"
+if [ -x "$CLIENT_DIR/mariadb-dump" ]; then
+ MYSQLDUMP="$CLIENT_DIR/mariadb-dump"
else
+<<<<<<< HEAD
MYSQLDUMP="$(command -v mysqldump)"
+||||||| constructed merge base
+ MYSQLDUMP=mysqldump
+=======
+ MYSQLDUMP=mariadb-dump
+>>>>>>> MDEV-22010: use executables MariaDB named in scripts
fi
if [ -x "$SCRIPTS_DIR/my_print_defaults" ]; then
diff --git a/scripts/mysqlaccess.sh b/scripts/mysqlaccess.sh
index aaf711b0fb9..f6dbee75b87 100644
--- a/scripts/mysqlaccess.sh
+++ b/scripts/mysqlaccess.sh
@@ -35,7 +35,7 @@ BEGIN {
# ****************************
# information on MariaDB
- $MYSQL = '@bindir@/mysql'; # path to mysql executable
+ $MYSQL = '@bindir@/mariadb'; # path to mariadb executable
$SERVER = '3.21';
$MYSQL_OPT = ' --batch --unbuffered';
$ACCESS_DB = 'mysql'; # name of DB with grant-tables
@@ -50,8 +50,8 @@ BEGIN {
$ACCESS_U_BCK = 'user_backup';
$ACCESS_D_BCK = 'db_backup';
$DIFF = '/usr/bin/diff';
- $MYSQLDUMP = '@bindir@/mysqldump';
- #path to mysqldump executable
+ $MYSQLDUMP = '@bindir@/mariadb-dump';
+ #path to mariadb-dump executable
$MYSQLADMIN= 'http://foobar.com/MySQLadmin';
#URL of CGI for manipulating
diff --git a/scripts/mysqld_multi.sh b/scripts/mysqld_multi.sh
index 77ed36218d3..51cb052bde0 100644
--- a/scripts/mysqld_multi.sh
+++ b/scripts/mysqld_multi.sh
@@ -29,8 +29,8 @@ my @defaults_options; # Leading --no-defaults, --defaults-file, etc.
$opt_example = 0;
$opt_help = 0;
$opt_log = undef();
-$opt_mysqladmin = "@bindir@/mysqladmin";
-$opt_mysqld = "@sbindir@/mysqld";
+$opt_mysqladmin = "@bindir@/mariadb-admin";
+$opt_mysqld = "@sbindir@/mariadbd";
$opt_no_log = 0;
$opt_password = undef();
$opt_tcp_ip = 0;
@@ -360,9 +360,9 @@ sub start_mysqlds()
$tmp.= " $options[$j]";
}
}
- if ($opt_verbose && $com =~ m/\/(safe_mysqld|mysqld_safe)$/ && !$info_sent)
+ if ($opt_verbose && $com =~ m/\/(mariadbd-safe)$/ && !$info_sent)
{
- print "WARNING: $1 is being used to start mysqld. In this case you ";
+ print "WARNING: $1 is being used to start mariadbd. In this case you ";
print "may need to pass\n\"ledir=...\" under groups [mysqldN] to ";
print "$1 in order to find the actual mysqld binary.\n";
print "ledir (library executable directory) should be the path to the ";
@@ -680,14 +680,14 @@ sub example
#
# 2.PID-FILE
#
# If you are using mysqld_safe to start mysqld, make sure that every
# MariaDB server has a separate pid-file. In order to use mysqld_safe
# via $my_progname, you need to use two options:
#
-# mysqld=/path/to/mysqld_safe
-# ledir=/path/to/mysqld-binary/
+# mysqld=/path/to/mariadbd-safe
+# ledir=/path/to/mariadbd-binary/
#
# ledir (library executable directory), is an option that only mysqld_safe
# accepts, so you will get an error if you try to pass it to mysqld directly.
# For this reason you might want to use the above options within [mysqld#]
# group directly.
@@ -740,8 +740,8 @@ sub example
#
[mysqld_multi]
-mysqld = @bindir@/mysqld_safe
-mysqladmin = @bindir@/mysqladmin
+mysqld = @bindir@/mariadbd-safe
+mysqladmin = @bindir@/mariadb-admin
user = multi_admin
password = my_password
@@ -754,9 +754,9 @@ language = @datadir@/mysql/english
user = unix_user1
[mysqld3]
-mysqld = /path/to/mysqld_safe
-ledir = /path/to/mysqld-binary/
-mysqladmin = /path/to/mysqladmin
+mysqld = /path/to/mariadbd-safe
+ledir = /path/to/mariadbd-binary/
+mysqladmin = /path/to/mariadb-admin
socket = /tmp/mysql.sock3
port = 3308
pid-file = @localstatedir@3/hostname.pid3
@@ -841,9 +841,9 @@ Using: @{[join ' ', @defaults_options]}
--mysqladmin=... mysqladmin binary to be used for a server shutdown.
Since version 2.10 this can be given within groups [mysqld#]
Using: $mysqladmin
---mysqld=... mysqld binary to be used. Note that you can give mysqld_safe
+--mysqld=... mariadbd binary to be used. Note that you can give mariadbd-safe
to this option also. The options are passed to mysqld. Just
- make sure you have mysqld in your PATH or fix mysqld_safe.
+ make sure you have mariadbd in your PATH or fix mariadbd-safe.
Using: $mysqld
Please note: Since mysqld_multi version 2.3 you can also
give this option inside groups [mysqld#] in ~/.my.cnf,
@@ -680,14 +680,14 @@ sub example
# 2.PID-FILE
#
-# If you are using mysqld_safe to start mysqld, make sure that every
-# MariaDB server has a separate pid-file. In order to use mysqld_safe
+# If you are using mariadbd-safe to start mariadbd, make sure that every
+# MariaDB server has a separate pid-file. In order to use mariadbd-safe
# via $my_progname, you need to use two options:
#
@@ -680,14 +680,14 @@ sub example
#
-# ledir (library executable directory), is an option that only mysqld_safe
+# ledir (library executable directory), is an option that only mariadbd-safe
# accepts, so you will get an error if you try to pass it to mysqld directly.
# For this reason you might want to use the above options within [mysqld#]